/*
============================================================================
 Name		: RDAccelerometerObserver.h
 Author	  : Markus Khri
 Copyright   : Copyright Nokia
 Description : RDAccelerometerObserver.h - Accelerometer observer class header
============================================================================
*/

// This file defines the API for RDAccelerometer.dll

#ifndef __RDACCELEROMETEROBSERVER_H__
#define __RDACCELEROMETEROBSERVER_H__


//  Include Files


//  Constants


// CLASS DECLARATION
/**
 * MRDAccelerometerObserver
 *  Mixin class.
 *  Observer which handles accelerataion data.
 */
class MRDAccelerometerObserver
	{
public:

	/**
	 * HandleAccelerationData.
	 * Handle acceleration data from the server.
	 *  - 1G acceleration is equal to 64
	 *  - 0G acceleration is equal to 0
	 *  - (-1G) acceleration is equal to (-63)
	 * 
	 *  Main display up              -> x ~=   0, y ~=   0, z ~= -63
	 *  Main display down            -> x ~=   0, y ~=   0, z ~=  64
	 *  USB port down                -> x ~=   0, y ~=  64, z ~=   0
	 *  USB port up                  -> x ~=   0, y ~= -63, z ~=   0
	 *  Camera keys up               -> x ~= -64, y ~=   0, z ~=   0
	 *  Camera keys down             -> x ~=  63, y ~=   0, z ~=   0
	 * 
	 */
	virtual void HandleAccelerationL(TInt aX, TInt aY, TInt aZ) = 0;
	
	};


#endif  // __RDACCELEROMETEROBSERVER_H__


